#ifndef __PERL_MSGPACK_UTIL_H__
#define __PERL_MSGPACK_UTIL_H__

#if __GNUC__ >= 3
# define INLINE                     inline
#else
# define INLINE                     
#endif

#endif // __PERL_MSGPACK_UTIL_H__

